from setuptools import setup, find_packages

setup(
    name = "inukit",
    packages = ['inukit'],
    version = "0.9",
    license = 'MIT',
    description = "Kit by & for inuEbisu",
    author = "inuEbisu",
    author_email = "inuebisu@qq.com",
    url = "https://inuebisu.cn", 
    keywords = ['inukit']
)